![GitHub](https://img.shields.io/github/license/gondixyz/python-sdk)

Gondi Python SDK


Local setup:
- Download poetry: `pip install poetry`
- Clone repo: `mkdir gondi && cd gondi && git clone https://github.com/gondixyz/python-sdk.git && cd python-sdk`
- `poetry install` 

Running local node (For more info visit: https://book.getfoundry.sh/):
 - Download foundry: `curl -L https://foundry.paradigm.xyz | bash` 
 - `foundryup`
 - Run anvil node: `anvil`
